<?php defined('FLATBOARD') or die('Flatboard Community.');
/**
 * SnowFlakes
 *
 * @author 		Frédéric K.
 * @copyright	(c) 2021-2022
 * @license		http://opensource.org/licenses/MIT
 * @package		Flatboard
 * @version		1.0
 * @update		2021-12-10
 */	
 
/**
 * On pré-installe les paramètres par défauts.
**/
function SnowFlakes_install()
{
	global $lang; 	
	$plugin = 'SnowFlakes';
	if (flatDB::isValidEntry('plugin', $plugin))
		return;
	# Activation de certains paramètres
    $data[$plugin.'state']				= false;
    # Données de personnalisation 
	$data[$plugin.'snowmax']     = '35';
	$data[$plugin.'snowcolor']   = '#aaaacc';
	$data[$plugin.'snowtype']    = 'Times';
	$data[$plugin.'snowletter']  = '*';
	$data[$plugin.'sinkspeed']   = '0.7';
	$data[$plugin.'snowmaxsize'] = '30'; 
	$data[$plugin.'snowminsize'] = '8';
	$data[$plugin.'snowingzone'] = '1';  
    # On sauvegarde la configuration par défault du plugin      
	flatDB::saveEntry('plugin', $plugin, $data);
}

/**
 * Admin
**/
function SnowFlakes_config()
{    
	   global $lang, $token; 
       $plugin = 'SnowFlakes';
       $out ='';    
       if(!empty($_POST) && CSRF::check($token) )
       {
       	   # Activation de certains paramètres
           $data[$plugin.'state'] 			= Util::isPOST('state') ? $_POST['state'] : '';   
           # Données de personnalisation
           $data[$plugin.'snowmax']			= HTMLForm::clean($_POST['snowmax']); 
           $data[$plugin.'snowcolor']		= HTMLForm::clean($_POST['snowcolor']);  
           $data[$plugin.'snowtype']		= HTMLForm::clean($_POST['snowtype']);
           $data[$plugin.'snowletter']		= HTMLForm::clean($_POST['snowletter']);
           $data[$plugin.'sinkspeed']		= HTMLForm::clean($_POST['sinkspeed']);
           $data[$plugin.'snowmaxsize']		= HTMLForm::clean($_POST['snowmaxsize']);
           $data[$plugin.'snowminsize']		= HTMLForm::clean($_POST['snowminsize']);
           $data[$plugin.'snowingzone']		= HTMLForm::clean($_POST['snowingzone']);                          
           flatDB::saveEntry('plugin', $plugin, $data);
           $out .= Plugin::redirectMsg($lang['data_save'],'config.php' . DS . 'plugin' . DS . $plugin, $lang['plugin'].'&nbsp;<b>' .$lang[$plugin.'name']. '</b>');
       }
        else
       {
           if (flatDB::isValidEntry('plugin', $plugin))
           $data = flatDB::readEntry('plugin', $plugin);
           $out .= HTMLForm::form('config.php' . DS . 'plugin' . DS . $plugin,'
			<div class="row">
			    <div class="col">'.
			    	HTMLForm::checkBox('state', $data[$plugin.'state']).
			    '</div>
			</div>  
			             
			<div class="row">
			    <div class="col">'.
			    	HTMLForm::text('snowmax', isset($data)? $data[$plugin.'snowmax'] : '', 'number').
			    '</div>
			    <div class="col">'.
			    	HTMLForm::text('snowcolor', isset($data)? $data[$plugin.'snowcolor'] : '', 'color'). 
			    '</div>
			    <div class="col">'.
			    	HTMLForm::text('snowtype', isset($data)? $data[$plugin.'snowtype'] : '', 'text').
			    '</div>
			    <div class="col">'.
			    	HTMLForm::text('snowletter', isset($data)? $data[$plugin.'snowletter'] : '').
			    '</div>				    
			</div>
			
			<div class="row">
			    <div class="col">'.
			    	HTMLForm::text('sinkspeed', isset($data)? $data[$plugin.'sinkspeed'] : '', 'number').
			    '</div>
			    <div class="col">'.
			    	HTMLForm::text('snowmaxsize', isset($data)? $data[$plugin.'snowmaxsize'] : '', 'number'). 
			    '</div>
			    <div class="col">'.
			    	HTMLForm::text('snowminsize', isset($data)? $data[$plugin.'snowminsize'] : '', 'number').
			    '</div>
			    <div class="col">'.
			    	HTMLForm::text('snowingzone', isset($data)? $data[$plugin.'snowingzone'] : '', 'number'). 
			    '</div>
			</div>'.               
           HTMLForm::simple_submit());
       }
       return $out;
} 

/** 
 * Ajoute du Javascript en pied de page du thème (footer.tpl.php)
 */
function SnowFlakes_footerJS() { 
	global $lang;
  	$plugin = 'SnowFlakes';
  	# Lecture des données
  	$data = flatDB::readEntry('plugin', $plugin);
  	$out='';
  	$status = '';
  	$assets = HTML_PLUGIN_DIR. $plugin. DS. 'js' . DS;
  		 		
	if ($data[$plugin.'state']) {	
		$out .='	<script>'.PHP_EOL;
		$out .='
		// Set the number of snowflakes (more than 30 - 40 not recommended)
		var snowmax='.$data[$plugin.'snowmax'].'
		// Set the colors for the snow. Add as many colors as you like ("#aaaacc","#ddddff","#ccccdd","#f3f3f3","#f0ffff")
		var snowcolor=new Array("'.$data[$plugin.'snowcolor'].'")
		// Set the fonts, that create the snowflakes. Add as many fonts as you like("Times","Arial","Times","Verdana")
		var snowtype=new Array("'.$data[$plugin.'snowtype'].'")
		// Set the letter that creates your snowflake (recommended: * )
		var snowletter="'.$data[$plugin.'snowletter'].'"
		// Set the speed of sinking (recommended values range from 0.3 to 2)
		var sinkspeed='.$data[$plugin.'sinkspeed'].'
		// Set the maximum-size of your snowflakes
		var snowmaxsize='.$data[$plugin.'snowmaxsize'].'
		// Set the minimal-size of your snowflakes
		var snowminsize='.$data[$plugin.'snowminsize'].'
		// Set the snowing-zone
		// Set 1 for all-over-snowing, set 2 for left-side-snowing
		// Set 3 for center-snowing, set 4 for right-side-snowing
		var snowingzone='.$data[$plugin.'snowingzone'].PHP_EOL;
		$out .='	</script>'.PHP_EOL;		
		$out .='	<script src="' .$assets. 'snowflakes.js?ver=1.0"></script>'.PHP_EOL;				        
	} 
	return $out; 
}